Function debug_enabled
pub fn debug_enabled() -> boolExpand description
Returns whether ZeroClaw DEBUG log events are enabled for the current subscriber. Use this before building expensive structured DEBUG attrs.
pub fn debug_enabled() -> boolReturns whether ZeroClaw DEBUG log events are enabled for the current subscriber. Use this before building expensive structured DEBUG attrs.