Function set_observer_bridge
pub fn set_observer_bridge(observer: Arc<dyn Observer>)Expand description
Install the bound Observer that the bridge forwards events to. Calling again replaces the previous binding.
pub fn set_observer_bridge(observer: Arc<dyn Observer>)Install the bound Observer that the bridge forwards events to. Calling again replaces the previous binding.